| all/1 | Conjunction of a list of booleans. |
| any/1 | Disjunction of a list of booleans. |
| droplast_n/2 | Drops the last N entries from the given list. |
| groups_of/2 | Splits a list of items into sublists of size equal to N. |
| intersperse/2 | Place the given value between all members of the given list. |
| shuffle/1 | Shuffle a list. |
| take/2 | Take the first N elements from the given list. |
| uniq/1 | Returns only unique elements from the given list, filtering out duplicates. |
all(Xs::[boolean()]) -> boolean()
Conjunction of a list of booleans. Returns true if and only if
all the booleans are true.
any(Xs::[boolean()]) -> boolean()
Disjunction of a list of booleans. Returns true if at least
one of the booleans is true.
droplast_n(N::non_neg_integer(), L::[X]) -> [X]
Drops the last N entries from the given list.
groups_of(N::pos_integer(), Xs::[Data]) -> [[Data]]
Splits a list of items into sublists of size equal to N
intersperse(X, L::[X]) -> [X]
Place the given value between all members of the given list.
shuffle(L) -> any()
Shuffle a list.
take(N::non_neg_integer(), Xs::[X]) -> [X]
Take the first N elements from the given list.
uniq(L::[A]) -> [A]
Returns only unique elements from the given list, filtering out duplicates.
Elements are considered to be different if they do not match (=:=).
Generated by EDoc